/* ControlManager.h - Menu suppor class to 
   the Control menu functions for the 
   Macintosh OS X SDL port of Atari800
   Mark Grebe <atarimac@cox.net>
   
   Based on the Preferences pane of the
   TextEdit application.

*/
#import <Cocoa/Cocoa.h>

#define kHistorySize 25

@interface ControlManager : NSObject
{
    NSString *history[kHistorySize];
    int historySize;
    int historyIndex;
    int historyLine;
    IBOutlet id coldResetItem;
    IBOutlet id limitItem;
    IBOutlet id disableBasicItem;
    IBOutlet id cx85EnableItem;
    IBOutlet id keyjoyEnableItem;
    IBOutlet id loadStateItem;
    IBOutlet id pauseItem;
    IBOutlet id saveStateItem;
    IBOutlet id warmResetItem;
    IBOutlet id errorTextField;
    IBOutlet id messageOutputView;
    IBOutlet id monitorOutputView;
    IBOutlet id monitorInputField;
    IBOutlet id monitorExeButton;
    IBOutlet id monitorDoneButton;
	IBOutlet id machineTypeMenu;
	IBOutlet id pbiExpansionMenu;
	IBOutlet id arrowKeysMenu;
	IBOutlet id ctrlArrowKeysItem;
	IBOutlet id arrowKeysOnlyItem;
	IBOutlet id arrowKeysF1F4Item;
	IBOutlet id startButton;
}
+ (ControlManager *)sharedInstance;
- (void)setLimitMenu:(int)limit;
- (void)setDisableBasicMenu:(int)disableBasic;
- (void)setKeyjoyEnableMenu:(int)keyjoyEnable;
- (void)setCX85EnableMenu:(int)cx85Enable;
- (NSString *) browseFileInDirectory:(NSString *)directory;
- (NSString *) saveFileInDirectory:(NSString *)directory:(NSString *)type;
- (IBAction)coldReset:(id)sender;
- (IBAction)limit:(id)sender;
- (IBAction)disableBasic:(id)sender;
- (IBAction)keyjoyEnable:(id)sender;
- (IBAction)cx85Enable:(id)sender;
- (IBAction)loadState:(id)sender;
- (void)loadStateFile:(NSString *)filename;
- (IBAction)pause:(id)sender;
- (IBAction)saveState:(id)sender;
- (IBAction)warmReset:(id)sender;
- (int)fatalError;
- (IBAction)ejectCartridgeSelected:(id)sender;
- (IBAction)ejectDiskSelected:(id)sender;
- (IBAction)coldStartSelected:(id)sender;
- (IBAction)warmStartSelected:(id)sender;
- (IBAction)monitorSelected:(id)sender;
- (IBAction)quitSelected:(id)sender;
- (IBAction)changeMachineType:(id)sender;
- (IBAction)changePBIExpansion:(id)sender;
- (IBAction)changeArrowKeys:(id)sender;
- (void)setMachineTypeMenu:(int)machineType:(int)ramSize;
- (void)setPBIExpansionMenu:(int)type;
- (void)setArrowKeysMenu:(int)keys;
- (void) releaseKey:(int)keyCode;
- (IBAction)monitorExecute:(id)sender;
- (void)messagePrint:(char *)printString;
- (void)messageWindowShow:(id)sender;
- (NSPoint)messagesOriginSave;
- (NSPoint)functionKeysOriginSave;
- (NSPoint)monitorOriginSave;
- (void)monitorPrint:(char *)string;
- (IBAction)monitorMenuRun:(id)sender;
- (int)monitorRun;
- (void)addToHistory:(NSString *)str;
- (void)historyScroll:(int)direction;
- (NSString *)getHistoryString:(int)direction;
- (void)monitorUpArrow;
- (void)monitorDownArrow;
- (IBAction)showAboutBox:(id)sender;
- (IBAction)showDonation:(id)sender;
- (IBAction)breakPressed:(id)sender;
- (IBAction)startPressed:(id)sender;
- (IBAction)optionPressed:(id)sender;
- (IBAction)selectPressed:(id)sender;
- (IBAction)functionKeyWindowShow:(id)sender;
@end
